==> isddc-1.11.1-py3-none-any.whl: isddc/isddc_command.py <==
import subprocess


class IsddcCommand:
    exitcode = 0

    def __init__(self, cmd: str, *, timeout=None):
        self.cmd = cmd
        try:
            self.raw_output: str = subprocess.check_output(
                cmd,
                timeout=timeout,
                shell=True,
                universal_newlines=True,
                stderr=subprocess.STDOUT)
        except subprocess.CalledProcessError as e:
            self.raw_output: str = e.output
            self.exitcode: int = e.returncode

    def raise_if_error(self):
        if self.exitcode != 0:
            raise self.CommandError(f'({self.cmd}) {self.output}')

    @property
    def status(self) -> bool:
        return False if self.exitcode else True

    @property
    def output(self) -> str:
        if self.raw_output[-1:] == '\n':
            return self.raw_output[:-1]
        return self.raw_output

    @property
    def status_output(self) -> tuple:
        return self.status, self.output

    @property
    def exitcode_output(self) -> tuple:
        return self.exitcode, self.output

    @property
    def output_else_raise(self) -> str:
        if self.exitcode == 0:
            return self.output
        raise self.CommandError(f'({self.cmd}) {self.output}')

    @property
    def output_else_define(self, define=None):
        return self.output if self.exitcode == 0 else define

    def is_contain_string(self, string: str) -> bool:
        if string in self.raw_output:
            return True
        return False

    def output_if_contain_string_else_raise(self, string: str) -> str:
        if string in self.raw_output:
            return self.output
        raise self.CommandError(f'({self.cmd}): "{self.output}"')

    def table_output_to_dict(self, **kw) -> list:
        return self.table2dict(self.output_else_raise, **kw)

    @classmethod
    def table2dict(cls, table: str, *, split: str = None) -> list:
        """Used to turn the command output result with a title
        into a dictionary, such as `kubectl get pod -n isddc`."""
        result = [[value.strip() for value in line.split(split)]
                  for line in table.splitlines()]
        keys = [key.lower() for key in result[0]]
        return [dict(zip(keys, values)) for values in result[1:]]

    class CommandError(Exception):
        pass

==> isddc-3.1.0-py3-none-any.whl: isddc/isddc_command.py <==
import subprocess


class IsddcCommand:
    code = 0

    def __init__(self, cmd: str, *, timeout: int = None):
        self.cmd = cmd
        try:
            self.raw_output: str = subprocess.check_output(
                cmd,
                timeout=timeout,
                shell=True,
                universal_newlines=True,
                stderr=subprocess.STDOUT)
        except subprocess.CalledProcessError as e:
            self.raw_output: str = e.output
            self.code: int = e.returncode

    def raise_if_error(self):
        if self.code != 0:
            raise self.CommandError(f'({self.cmd}) {self.output}')

    @property
    def status(self) -> bool:
        return False if self.code else True

    @property
    def output(self) -> str:
        if self.raw_output[-1:] == '\n':
            return self.raw_output[:-1]
        return self.raw_output

    @property
    def status_output(self) -> tuple:
        return self.status, self.output

    @property
    def code_output(self) -> tuple:
        return self.code, self.output

    @property
    def output_else_raise(self) -> str:
        if self.code == 0:
            return self.output
        raise self.CommandError(f'({self.cmd}) {self.output}')

    @property
    def output_else_define(self, define=None):
        return self.output if self.code == 0 else define

    def is_contain_string(self, string: str) -> bool:
        if string in self.raw_output:
            return True
        return False

    def output_if_contain_string_else_raise(self, string: str) -> str:
        if string in self.raw_output:
            return self.output
        raise self.CommandError(f'({self.cmd}): "{self.output}"')

    def table_output_to_dict(self, **kw) -> list:
        return self.table2dict(self.output_else_raise, **kw)

    @classmethod
    def table2dict(cls, table: str, *, split: str = None) -> list:
        """Used to turn the command output result with a title
        into a dictionary, such as `kubectl get pod -n isddc`."""
        result = [[value.strip() for value in line.split(split)]
                  for line in table.splitlines()]
        keys = [key.lower() for key in result[0]]
        return [dict(zip(keys, values)) for values in result[1:]]

    class CommandError(Exception):
        pass
